# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.1.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _medlink
else:
    import _medlink

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator_medlink_module(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medlink.delete_SwigPyIterator_medlink_module

    def value(self):
        return _medlink.SwigPyIterator_medlink_module_value(self)

    def incr(self, n=1):
        return _medlink.SwigPyIterator_medlink_module_incr(self, n)

    def decr(self, n=1):
        return _medlink.SwigPyIterator_medlink_module_decr(self, n)

    def distance(self, x):
        return _medlink.SwigPyIterator_medlink_module_distance(self, x)

    def equal(self, x):
        return _medlink.SwigPyIterator_medlink_module_equal(self, x)

    def copy(self):
        return _medlink.SwigPyIterator_medlink_module_copy(self)

    def next(self):
        return _medlink.SwigPyIterator_medlink_module_next(self)

    def __next__(self):
        return _medlink.SwigPyIterator_medlink_module___next__(self)

    def previous(self):
        return _medlink.SwigPyIterator_medlink_module_previous(self)

    def advance(self, n):
        return _medlink.SwigPyIterator_medlink_module_advance(self, n)

    def __eq__(self, x):
        return _medlink.SwigPyIterator_medlink_module___eq__(self, x)

    def __ne__(self, x):
        return _medlink.SwigPyIterator_medlink_module___ne__(self, x)

    def __iadd__(self, n):
        return _medlink.SwigPyIterator_medlink_module___iadd__(self, n)

    def __isub__(self, n):
        return _medlink.SwigPyIterator_medlink_module___isub__(self, n)

    def __add__(self, n):
        return _medlink.SwigPyIterator_medlink_module___add__(self, n)

    def __sub__(self, *args):
        return _medlink.SwigPyIterator_medlink_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self

# Register SwigPyIterator_medlink_module in _medlink:
_medlink.SwigPyIterator_medlink_module_swigregister(SwigPyIterator_medlink_module)
HAVE_CC_C99 = _medlink.HAVE_CC_C99
HAVE_CUSERID = _medlink.HAVE_CUSERID
HAVE_DLFCN_H = _medlink.HAVE_DLFCN_H
HAVE_FTIME = _medlink.HAVE_FTIME
HAVE_GETEUID = _medlink.HAVE_GETEUID
HAVE_GETPWUID = _medlink.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medlink.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medlink.HAVE_H5PUBLIC_H
HAVE_INT64 = _medlink.HAVE_INT64
HAVE_INTTYPES_H = _medlink.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medlink.HAVE_MALLOC_H
HAVE_PWD_H = _medlink.HAVE_PWD_H
HAVE_STDBOOL_H = _medlink.HAVE_STDBOOL_H
HAVE_STDINT_H = _medlink.HAVE_STDINT_H
HAVE_STDIO_H = _medlink.HAVE_STDIO_H
HAVE_STDLIB_H = _medlink.HAVE_STDLIB_H
HAVE_STRINGS_H = _medlink.HAVE_STRINGS_H
HAVE_STRING_H = _medlink.HAVE_STRING_H
HAVE_SYS_STAT_H = _medlink.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medlink.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medlink.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medlink.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medlink.HAVE_UNISTD_H
HAVE__BOOL = _medlink.HAVE__BOOL
MED_CHECK_23FORMAT = _medlink.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medlink.MED_HAVE_FORTRAN
MESGERR = _medlink.MESGERR
PACKAGE = _medlink.PACKAGE
PACKAGE_BUGREPORT = _medlink.PACKAGE_BUGREPORT
PACKAGE_NAME = _medlink.PACKAGE_NAME
PACKAGE_STRING = _medlink.PACKAGE_STRING
PACKAGE_URL = _medlink.PACKAGE_URL
PACKAGE_VERSION = _medlink.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medlink.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medlink.SIZEOF_INT
SIZEOF_LONG = _medlink.SIZEOF_LONG
STDC_HEADERS = _medlink.STDC_HEADERS
VERSION = _medlink.VERSION
HDF_VERSION_REF = _medlink.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medlink.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medlink.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medlink.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medlink.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medlink.H5F_LIBVER_18
MED_MAJOR_NUM = _medlink.MED_MAJOR_NUM
MED_MINOR_NUM = _medlink.MED_MINOR_NUM
MED_RELEASE_NUM = _medlink.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medlink.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medlink.MED_4_LATEST_MINOR
MED_40_LATEST_RELEASE = _medlink.MED_40_LATEST_RELEASE
MED_NUM_MAJEUR = _medlink.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medlink.MED_NUM_MINEUR
MED_NUM_RELEASE = _medlink.MED_NUM_RELEASE
MED_VERSION_STR = _medlink.MED_VERSION_STR
MED_MAX_PARA = _medlink.MED_MAX_PARA
MED_COMMENT_SIZE = _medlink.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medlink.MED_IDENT_SIZE
MED_NAME_SIZE = _medlink.MED_NAME_SIZE
MED_SNAME_SIZE = _medlink.MED_SNAME_SIZE
MED_LNAME_SIZE = _medlink.MED_LNAME_SIZE
MED_SNAME_BLANK = _medlink.MED_SNAME_BLANK
MED_NAME_BLANK = _medlink.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medlink.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medlink.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medlink.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medlink.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medlink.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medlink.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medlink.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medlink.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medlink.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medlink.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medlink.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medlink.MED_ACC_RDONLY
MED_ACC_RDWR = _medlink.MED_ACC_RDWR
MED_ACC_RDEXT = _medlink.MED_ACC_RDEXT
MED_ACC_CREAT = _medlink.MED_ACC_CREAT
MED_ACC_UNDEF = _medlink.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medlink.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medlink.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medlink.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medlink.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medlink.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medlink.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medlink.MED_UNDEF_GRID_TYPE
MED_CELL = _medlink.MED_CELL
MED_DESCENDING_FACE = _medlink.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medlink.MED_DESCENDING_EDGE
MED_NODE = _medlink.MED_NODE
MED_NODE_ELEMENT = _medlink.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medlink.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medlink.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medlink.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medlink.MED_N_ENTITY_TYPES
MED_COORDINATE = _medlink.MED_COORDINATE
MED_CONNECTIVITY = _medlink.MED_CONNECTIVITY
MED_NAME = _medlink.MED_NAME
MED_NUMBER = _medlink.MED_NUMBER
MED_FAMILY_NUMBER = _medlink.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medlink.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medlink.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medlink.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medlink.MED_INDEX_FACE
MED_INDEX_NODE = _medlink.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medlink.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medlink.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medlink.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medlink.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medlink.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medlink.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medlink.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medlink.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medlink.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medlink.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medlink.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medlink.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medlink.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medlink.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medlink.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medlink.MED_INTERNAL_UNDEF
MED_DOUBLE = _medlink.MED_DOUBLE
MED_FLOAT64 = _medlink.MED_FLOAT64
MED_FLOAT32 = _medlink.MED_FLOAT32
MED_INT32 = _medlink.MED_INT32
MED_INT64 = _medlink.MED_INT64
MED_INT = _medlink.MED_INT
MED_ATT_FLOAT64 = _medlink.MED_ATT_FLOAT64
MED_ATT_INT = _medlink.MED_ATT_INT
MED_ATT_NAME = _medlink.MED_ATT_NAME
MED_ATT_UNDEF = _medlink.MED_ATT_UNDEF
MED_MESH = _medlink.MED_MESH
MED_FIELD = _medlink.MED_FIELD
MED_LIBRARY = _medlink.MED_LIBRARY
MED_FILE = _medlink.MED_FILE
MED_MESH_SUPPORT = _medlink.MED_MESH_SUPPORT
MED_ELSTRUCT = _medlink.MED_ELSTRUCT
MED_FAMILY = _medlink.MED_FAMILY
MED_EQUIVALENCE = _medlink.MED_EQUIVALENCE
MED_GROUP = _medlink.MED_GROUP
MED_JOINT = _medlink.MED_JOINT
MED_LOCALIZATION = _medlink.MED_LOCALIZATION
MED_PROFILE = _medlink.MED_PROFILE
MED_FILTER = _medlink.MED_FILTER
MED_INTERPOLATION = _medlink.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medlink.MED_NUMERICAL_DATA
MED_LINK = _medlink.MED_LINK
MED_CLASS_UNDEF = _medlink.MED_CLASS_UNDEF
MED_CLASS_ALL = _medlink.MED_CLASS_ALL
MED_POINT1 = _medlink.MED_POINT1
MED_SEG2 = _medlink.MED_SEG2
MED_SEG3 = _medlink.MED_SEG3
MED_SEG4 = _medlink.MED_SEG4
MED_TRIA3 = _medlink.MED_TRIA3
MED_QUAD4 = _medlink.MED_QUAD4
MED_TRIA6 = _medlink.MED_TRIA6
MED_TRIA7 = _medlink.MED_TRIA7
MED_QUAD8 = _medlink.MED_QUAD8
MED_QUAD9 = _medlink.MED_QUAD9
MED_TETRA4 = _medlink.MED_TETRA4
MED_PYRA5 = _medlink.MED_PYRA5
MED_PENTA6 = _medlink.MED_PENTA6
MED_HEXA8 = _medlink.MED_HEXA8
MED_TETRA10 = _medlink.MED_TETRA10
MED_OCTA12 = _medlink.MED_OCTA12
MED_PYRA13 = _medlink.MED_PYRA13
MED_PENTA15 = _medlink.MED_PENTA15
MED_PENTA18 = _medlink.MED_PENTA18
MED_HEXA20 = _medlink.MED_HEXA20
MED_HEXA27 = _medlink.MED_HEXA27
MED_POLYGON = _medlink.MED_POLYGON
MED_POLYGON2 = _medlink.MED_POLYGON2
MED_POLYHEDRON = _medlink.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medlink.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medlink.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medlink.MED_NONE
MED_NO_GEOTYPE = _medlink.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medlink.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medlink.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medlink.MED_ALL_GEOTYPE
MED_GEO_ALL = _medlink.MED_GEO_ALL
MED_N_CELL_GEO = _medlink.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medlink.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medlink.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medlink.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medlink.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medlink.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medlink.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medlink.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medlink.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medlink.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medlink.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medlink.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medlink.MED_NODAL
MED_DESCENDING = _medlink.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medlink.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medlink.MED_NO_CMODE
MED_CARTESIAN = _medlink.MED_CARTESIAN
MED_CYLINDRICAL = _medlink.MED_CYLINDRICAL
MED_SPHERICAL = _medlink.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medlink.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medlink.MED_FALSE
MED_TRUE = _medlink.MED_TRUE
MED_GAUSS_ELNO = _medlink.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medlink.MED_IPOINT_ELNO
MED_NO_NAME = _medlink.MED_NO_NAME
MED_NO_MESHNAME = _medlink.MED_NO_MESHNAME
MED_NO_MESH = _medlink.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medlink.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medlink.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medlink.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medlink.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medlink.MED_NO_PROFILE
MED_NO_GROUP = _medlink.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medlink.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medlink.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medlink.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medlink.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medlink.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medlink.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medlink.MED_SORT_DTIT
MED_SORT_ITDT = _medlink.MED_SORT_ITDT
MED_SORT_UNDEF = _medlink.MED_SORT_UNDEF
MED_ALL_DT = _medlink.MED_ALL_DT
MED_ALL_IT = _medlink.MED_ALL_IT
MED_NO_DT = _medlink.MED_NO_DT
MED_NO_IT = _medlink.MED_NO_IT
MED_UNDEF_DT = _medlink.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medlink.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medlink.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medlink.med_filter_nspaces_get, _medlink.med_filter_nspaces_set)
    memspace = property(_medlink.med_filter_memspace_get, _medlink.med_filter_memspace_set)
    diskspace = property(_medlink.med_filter_diskspace_get, _medlink.med_filter_diskspace_set)
    nentity = property(_medlink.med_filter_nentity_get, _medlink.med_filter_nentity_set)
    nvaluesperentity = property(_medlink.med_filter_nvaluesperentity_get, _medlink.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medlink.med_filter_nconstituentpervalue_get, _medlink.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medlink.med_filter_constituentselect_get, _medlink.med_filter_constituentselect_set)
    switchmode = property(_medlink.med_filter_switchmode_get, _medlink.med_filter_switchmode_set)
    filterarraysize = property(_medlink.med_filter_filterarraysize_get, _medlink.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medlink.med_filter_filterarray23v30_get, _medlink.med_filter_filterarray23v30_set)
    profilearraysize = property(_medlink.med_filter_profilearraysize_get, _medlink.med_filter_profilearraysize_set)
    storagemode = property(_medlink.med_filter_storagemode_get, _medlink.med_filter_storagemode_set)
    profilename = property(_medlink.med_filter_profilename_get, _medlink.med_filter_profilename_set)

    def __init__(self):
        r"""__init__(self) -> med_filter"""
        _medlink.med_filter_swiginit(self, _medlink.new_med_filter())
    __swig_destroy__ = _medlink.delete_med_filter

# Register med_filter in _medlink:
_medlink.med_filter_swigregister(med_filter)
MED_NO_FILTER_SIZE = _medlink.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medlink.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medlink.med_file_version_majeur_get, _medlink.med_file_version_majeur_set)
    mineur = property(_medlink.med_file_version_mineur_get, _medlink.med_file_version_mineur_set)
    release = property(_medlink.med_file_version_release_get, _medlink.med_file_version_release_set)

    def __init__(self):
        r"""__init__(self) -> med_file_version"""
        _medlink.med_file_version_swiginit(self, _medlink.new_med_file_version())
    __swig_destroy__ = _medlink.delete_med_file_version

# Register med_file_version in _medlink:
_medlink.med_file_version_swigregister(med_file_version)
class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medlink.med_memfile_app_image_ptr_get, _medlink.med_memfile_app_image_ptr_set)
    app_image_size = property(_medlink.med_memfile_app_image_size_get, _medlink.med_memfile_app_image_size_set)
    ref_count = property(_medlink.med_memfile_ref_count_get, _medlink.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medlink.med_memfile_fapl_image_ptr_get, _medlink.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medlink.med_memfile_fapl_image_size_get, _medlink.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medlink.med_memfile_fapl_ref_count_get, _medlink.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medlink.med_memfile_vfd_image_ptr_get, _medlink.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medlink.med_memfile_vfd_image_size_get, _medlink.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medlink.med_memfile_vfd_ref_count_get, _medlink.med_memfile_vfd_ref_count_set)
    flags = property(_medlink.med_memfile_flags_get, _medlink.med_memfile_flags_set)

    def __init__(self):
        r"""__init__(self) -> med_memfile"""
        _medlink.med_memfile_swiginit(self, _medlink.new_med_memfile())
    __swig_destroy__ = _medlink.delete_med_memfile

# Register med_memfile in _medlink:
_medlink.med_memfile_swigregister(med_memfile)

def MEDgetEntityTypeIt(entitytype):
    return _medlink.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medlink.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medlink.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medlink.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medlink.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medlink.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medlink.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medlink.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medlink.MED_PARTICLE_NAME
MED_BALL_NAME = _medlink.MED_BALL_NAME
MED_BEAM_NAME = _medlink.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medlink.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medlink.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medlink.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlink.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlink.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medlink.MEDBOOL___bool__(self)

    def __len__(self):
        return _medlink.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medlink.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlink.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlink.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlink.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlink.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlink.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medlink.MEDBOOL_pop(self)

    def append(self, x):
        return _medlink.MEDBOOL_append(self, x)

    def empty(self):
        return _medlink.MEDBOOL_empty(self)

    def size(self):
        return _medlink.MEDBOOL_size(self)

    def swap(self, v):
        return _medlink.MEDBOOL_swap(self, v)

    def begin(self):
        return _medlink.MEDBOOL_begin(self)

    def end(self):
        return _medlink.MEDBOOL_end(self)

    def rbegin(self):
        return _medlink.MEDBOOL_rbegin(self)

    def rend(self):
        return _medlink.MEDBOOL_rend(self)

    def clear(self):
        return _medlink.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medlink.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medlink.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medlink.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        _medlink.MEDBOOL_swiginit(self, _medlink.new_MEDBOOL(*args))

    def push_back(self, x):
        return _medlink.MEDBOOL_push_back(self, x)

    def front(self):
        return _medlink.MEDBOOL_front(self)

    def back(self):
        return _medlink.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medlink.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medlink.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medlink.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medlink.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medlink.MEDBOOL_capacity(self)
    __swig_destroy__ = _medlink.delete_MEDBOOL

# Register MEDBOOL in _medlink:
_medlink.MEDBOOL_swigregister(MEDBOOL)
cvar = _medlink.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlink.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlink.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medlink.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medlink.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medlink.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlink.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlink.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlink.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlink.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlink.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medlink.MEDFLOAT_pop(self)

    def append(self, x):
        return _medlink.MEDFLOAT_append(self, x)

    def empty(self):
        return _medlink.MEDFLOAT_empty(self)

    def size(self):
        return _medlink.MEDFLOAT_size(self)

    def swap(self, v):
        return _medlink.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medlink.MEDFLOAT_begin(self)

    def end(self):
        return _medlink.MEDFLOAT_end(self)

    def rbegin(self):
        return _medlink.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medlink.MEDFLOAT_rend(self)

    def clear(self):
        return _medlink.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medlink.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medlink.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medlink.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        _medlink.MEDFLOAT_swiginit(self, _medlink.new_MEDFLOAT(*args))

    def push_back(self, x):
        return _medlink.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medlink.MEDFLOAT_front(self)

    def back(self):
        return _medlink.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medlink.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medlink.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medlink.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medlink.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medlink.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medlink.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medlink.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medlink.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medlink.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medlink.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medlink.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medlink.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medlink.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medlink.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medlink.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medlink.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medlink.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medlink.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medlink.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medlink.delete_MEDFLOAT

# Register MEDFLOAT in _medlink:
_medlink.MEDFLOAT_swigregister(MEDFLOAT)

MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlink.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlink.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medlink.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medlink.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medlink.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlink.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlink.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlink.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlink.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlink.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medlink.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medlink.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medlink.MEDFLOAT32_empty(self)

    def size(self):
        return _medlink.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medlink.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medlink.MEDFLOAT32_begin(self)

    def end(self):
        return _medlink.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medlink.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medlink.MEDFLOAT32_rend(self)

    def clear(self):
        return _medlink.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medlink.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medlink.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medlink.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        _medlink.MEDFLOAT32_swiginit(self, _medlink.new_MEDFLOAT32(*args))

    def push_back(self, x):
        return _medlink.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medlink.MEDFLOAT32_front(self)

    def back(self):
        return _medlink.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medlink.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medlink.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medlink.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medlink.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medlink.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medlink.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medlink.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medlink.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medlink.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medlink.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medlink.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medlink.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medlink.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medlink.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medlink.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medlink.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medlink.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medlink.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medlink.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medlink.delete_MEDFLOAT32

# Register MEDFLOAT32 in _medlink:
_medlink.MEDFLOAT32_swigregister(MEDFLOAT32)

MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlink.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlink.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medlink.MEDINT___bool__(self)

    def __len__(self):
        return _medlink.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medlink.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlink.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlink.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlink.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlink.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlink.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medlink.MEDINT_pop(self)

    def append(self, x):
        return _medlink.MEDINT_append(self, x)

    def empty(self):
        return _medlink.MEDINT_empty(self)

    def size(self):
        return _medlink.MEDINT_size(self)

    def swap(self, v):
        return _medlink.MEDINT_swap(self, v)

    def begin(self):
        return _medlink.MEDINT_begin(self)

    def end(self):
        return _medlink.MEDINT_end(self)

    def rbegin(self):
        return _medlink.MEDINT_rbegin(self)

    def rend(self):
        return _medlink.MEDINT_rend(self)

    def clear(self):
        return _medlink.MEDINT_clear(self)

    def get_allocator(self):
        return _medlink.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medlink.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medlink.MEDINT_erase(self, *args)

    def __init__(self, *args):
        _medlink.MEDINT_swiginit(self, _medlink.new_MEDINT(*args))

    def push_back(self, x):
        return _medlink.MEDINT_push_back(self, x)

    def front(self):
        return _medlink.MEDINT_front(self)

    def back(self):
        return _medlink.MEDINT_back(self)

    def assign(self, n, x):
        return _medlink.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medlink.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medlink.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medlink.MEDINT_reserve(self, n)

    def capacity(self):
        return _medlink.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medlink.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medlink.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medlink.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medlink.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medlink.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medlink.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medlink.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medlink.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medlink.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medlink.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medlink.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medlink.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medlink.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medlink.MEDINT___ne__(self, value)
    __swig_destroy__ = _medlink.delete_MEDINT

# Register MEDINT in _medlink:
_medlink.MEDINT_swigregister(MEDINT)

MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlink.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlink.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medlink.MEDCHAR___bool__(self)

    def __len__(self):
        return _medlink.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medlink.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlink.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlink.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlink.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlink.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlink.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medlink.MEDCHAR_pop(self)

    def append(self, x):
        return _medlink.MEDCHAR_append(self, x)

    def empty(self):
        return _medlink.MEDCHAR_empty(self)

    def size(self):
        return _medlink.MEDCHAR_size(self)

    def swap(self, v):
        return _medlink.MEDCHAR_swap(self, v)

    def begin(self):
        return _medlink.MEDCHAR_begin(self)

    def end(self):
        return _medlink.MEDCHAR_end(self)

    def rbegin(self):
        return _medlink.MEDCHAR_rbegin(self)

    def rend(self):
        return _medlink.MEDCHAR_rend(self)

    def clear(self):
        return _medlink.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medlink.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medlink.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medlink.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        _medlink.MEDCHAR_swiginit(self, _medlink.new_MEDCHAR(*args))

    def push_back(self, x):
        return _medlink.MEDCHAR_push_back(self, x)

    def front(self):
        return _medlink.MEDCHAR_front(self)

    def back(self):
        return _medlink.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medlink.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medlink.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medlink.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medlink.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medlink.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medlink.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medlink.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medlink.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medlink.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medlink.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medlink.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medlink.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medlink.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medlink.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medlink.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medlink.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medlink.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medlink.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medlink.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medlink.delete_MEDCHAR

# Register MEDCHAR in _medlink:
_medlink.MEDCHAR_swigregister(MEDCHAR)

MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDlinkWr(fid, meshname, link):
    r"""
    MEDlinkWr(fid, meshname, link) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    link: char const *const

    """
    return _medlink.MEDlinkWr(fid, meshname, link)

def MEDlinkRd(fid, meshname):
    r"""
    MEDlinkRd(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medlink.MEDlinkRd(fid, meshname)

def MEDnLink(fid):
    r"""
    MEDnLink(fid) -> med_int

    Parameters
    ----------
    fid: med_idt const

    """
    return _medlink.MEDnLink(fid)

def MEDlinkInfoByName(fid, meshname):
    r"""
    MEDlinkInfoByName(fid, meshname) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medlink.MEDlinkInfoByName(fid, meshname)

def MEDlinkInfo(fid, linkit):
    r"""
    MEDlinkInfo(fid, linkit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    linkit: int const

    """
    return _medlink.MEDlinkInfo(fid, linkit)

